Coverage for beyonic.errors: 100%

# Coverage for beyonic.errors : 100%

## 4 statements 4 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 | class BeyonicError(Exception): pass """ def __init__(self, message=None, http_body=None, http_status=None, json_body=None): super(BeyonicError, self).__init__(message) self.http_body = http_body self.http_status = http_status self.json_body = json_body """ class ResponseError(Exception): """ Raised when the Beyonic API responds with an HTTP error """ pass